%{?mingw_package_header}

%global majorver1 8
%global majorver2 6
%global majorver %{majorver1}.%{majorver2}
%global vers %{majorver}.12

%global pkgname tk

Summary:       MinGW Windows graphical toolkit for the Tcl scripting language
Name:          mingw-%{pkgname}
Version:       %{vers}
Release:    1%{?dist}
License:       TCL
URL:           http://tcl.sourceforge.net/
Source0:       http://downloads.sourceforge.net/sourceforge/tcl/%{pkgname}%{version}-src.tar.gz

BuildRequires: make
BuildRequires: mingw32-tcl = %{version}
BuildRequires: mingw32-filesystem >= 95
BuildRequires: mingw32-gcc

BuildRequires: mingw64-tcl = %{version}
BuildRequires: mingw64-filesystem >= 95
BuildRequires: mingw64-gcc

BuildArch: noarch

%description
When paired with the Tcl scripting language, Tk provides a fast and powerful
way to create cross-platform GUI applications.


%package -n mingw32-%{pkgname}
Summary:   MinGW Windows graphical toolkit for the Tcl scripting language

%description -n mingw32-%{pkgname}
When paired with the Tcl scripting language, Tk provides a fast and powerful
way to create cross-platform GUI applications.


%package -n mingw64-%{pkgname}
Summary:   MinGW Windows graphical toolkit for the Tcl scripting language

%description -n mingw64-%{pkgname}
When paired with the Tcl scripting language, Tk provides a fast and powerful
way to create cross-platform GUI applications.


%{?mingw_debug_package}


%prep
%autosetup -p1 -n %{pkgname}%{version}
iconv -f iso-8859-1 -t utf-8 changes > changes.utf8
touch -r changes changes.utf8
mv changes.utf8 changes


%build
pushd win

MINGW32_CONFIGURE_ARGS="--with-tcl=%{mingw32_libdir}/tcl%{majorver}"
MINGW64_CONFIGURE_ARGS="--with-tcl=%{mingw64_libdir}/tcl%{majorver}"
%{mingw_configure}
sed -i -e 's,mingw-tcl,tcl,g' build_win*/Makefile
sed -i -e 's,/usr/include,%{mingw32_includedir},g' build_win32/Makefile
sed -i -e 's,/usr/include,%{mingw64_includedir},g' build_win64/Makefile
sed -i -e 's,tcl8.6/libtclstub86,libtclstub86,g' build_win*/Makefile
sed -i -e 's,libtcl86.a,libtcl86.dll.a,g' build_win*/Makefile
sed -i -e 's,tcl8.6/libtcl86,libtcl86,g' build_win*/Makefile
%{mingw32_make} -C build_win32 TCL_LIBRARY=%{mingw32_datadir}/%{pkgname}%{majorver}
%{mingw64_make} -C build_win64 TCL_LIBRARY=%{mingw64_datadir}/%{pkgname}%{majorver}
popd


%install
make install -C win/build_win32 INSTALL_ROOT=%{buildroot} TK_LIBRARY=%{mingw32_datadir}/%{pkgname}%{majorver}
make install -C win/build_win64 INSTALL_ROOT=%{buildroot} TK_LIBRARY=%{mingw64_datadir}/%{pkgname}%{majorver}

ln -s wish%{majorver1}%{majorver2}.exe %{buildroot}%{mingw32_bindir}/wish.exe
ln -s wish%{majorver1}%{majorver2}.exe %{buildroot}%{mingw64_bindir}/wish.exe

ln -s lib%{pkgname}%{majorver1}%{majorver2}.dll.a \
      %{buildroot}%{mingw32_libdir}/lib%{pkgname}.dll.a
ln -s lib%{pkgname}%{majorver1}%{majorver2}.dll.a \
      %{buildroot}%{mingw64_libdir}/lib%{pkgname}.dll.a

mkdir -p %{buildroot}/%{mingw32_libdir}/%{pkgname}%{majorver}
mkdir -p %{buildroot}/%{mingw64_libdir}/%{pkgname}%{majorver}

ln -s %{mingw32_libdir}/%{pkgname}Config.sh \
      %{buildroot}/%{mingw32_libdir}/%{pkgname}%{majorver}/%{pkgname}Config.sh
ln -s %{mingw64_libdir}/%{pkgname}Config.sh \
      %{buildroot}/%{mingw64_libdir}/%{pkgname}%{majorver}/%{pkgname}Config.sh

mkdir -p %{buildroot}/%{mingw32_includedir}/%{pkgname}-private/{generic/ttk,win}
mkdir -p %{buildroot}/%{mingw64_includedir}/%{pkgname}-private/{generic/ttk,win}
find generic win -name "*.h" -exec cp -p '{}' %{buildroot}/%{mingw32_includedir}/%{pkgname}-private/'{}' ';'
find generic win -name "*.h" -exec cp -p '{}' %{buildroot}/%{mingw64_includedir}/%{pkgname}-private/'{}' ';'
( cd %{buildroot}/%{mingw32_includedir}
     for i in *.h ; do
         [ -f %{buildroot}/%{mingw32_includedir}/%{pkgname}-private/generic/$i ] && \
         ln -sf ../../$i %{buildroot}/%{mingw32_includedir}/%{pkgname}-private/generic ;
     done
) || true
( cd %{buildroot}/%{mingw64_includedir}
     for i in *.h ; do
         [ -f %{buildroot}/%{mingw64_includedir}/%{pkgname}-private/generic/$i ] && \
         ln -sf ../../$i %{buildroot}/%{mingw64_includedir}/%{pkgname}-private/generic ;
     done
) || true

chmod a-x %{buildroot}/%{mingw32_libdir}/*/pkgIndex.tcl
chmod a-x %{buildroot}/%{mingw64_libdir}/*/pkgIndex.tcl

sed -i -e "s|$PWD/win|%{_libdir}|; s|$PWD|%{_includedir}/%{name}-private|" %{buildroot}/%{mingw32_libdir}/%{pkgname}Config.sh
sed -i -e "s|$PWD/win|%{_libdir}|; s|$PWD|%{_includedir}/%{name}-private|" %{buildroot}/%{mingw64_libdir}/%{pkgname}Config.sh
rm -rf %{buildroot}/%{mingw32_datadir}/%{pkgname}%{majorver}/tclAppInit.c
rm -rf %{buildroot}/%{mingw64_datadir}/%{pkgname}%{majorver}/tclAppInit.c
rm -rf %{buildroot}/%{mingw32_datadir}/%{pkgname}%{majorver}/ldAix
rm -rf %{buildroot}/%{mingw64_datadir}/%{pkgname}%{majorver}/ldAix


%files -n mingw32-%{pkgname}
%{mingw32_bindir}/wish*.exe
%{mingw32_bindir}/%{pkgname}%{majorver1}%{majorver2}.dll
%{mingw32_libdir}/lib%{pkgname}%{majorver1}%{majorver2}.dll.a
%{mingw32_libdir}/lib%{pkgname}stub%{majorver1}%{majorver2}.a
%{mingw32_libdir}/lib%{pkgname}.dll.a
%{mingw32_libdir}/%{pkgname}Config.sh
%{mingw32_includedir}/*
%{mingw32_libdir}/%{pkgname}%{majorver}/
%{mingw32_datadir}/%{pkgname}%{majorver1}.%{majorver2}
%doc changes
%doc license.terms

%files -n mingw64-%{pkgname}
%{mingw64_bindir}/wish*.exe
%{mingw64_bindir}/%{pkgname}%{majorver1}%{majorver2}.dll
%{mingw64_libdir}/lib%{pkgname}%{majorver1}%{majorver2}.dll.a
%{mingw64_libdir}/lib%{pkgname}stub%{majorver1}%{majorver2}.a
%{mingw64_libdir}/lib%{pkgname}.dll.a
%{mingw64_libdir}/%{pkgname}Config.sh
%{mingw64_includedir}/*
%{mingw64_libdir}/%{pkgname}%{majorver}/
%{mingw64_datadir}/%{pkgname}%{majorver1}.%{majorver2}
%doc changes
%doc license.terms

%changelog
* Tue Aug 06 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 8.6.12-1
- initial build
